MPD_sima Automagically add titles to MPD playlist.
==================================================

MPD_sima_ is a non interactive MPD autoqueue client running in the background.
It will queue new tracks chosen among artists similar to your current queued
tracks, provided a title is found in your music library.

Similar artists are fetched from last.fm webservice.

MPD_sima can queue track, top track or whole album for similar artists.

This client allows you to never run out of music when your queue is getting
short.

.. _MPD_sima: https://kaliko.me/code/mpd-sima/
